//==========================================================================
//
//      fs6377.h
//
// Author(s):    Michael Kelly - Cogent Computer Systems, Inc.
// Date:         02/18/2002
// Description:  Defines and Macros for AMI FS6377 programmable PLL.
//
//==========================================================================

//--------------------------------------------------------------------------
// I2C Address
//
#define FS6377_I2C_ADD	0x58	// I2C Address of FS6377

//--------------------------------------------------------------------------
// Programmed values
//
// The following array data is derived from the
// the FS6377 Configuration Utility from AMI.
//
// All outputs but CLK0 are the same for each
// configuration.  The two configurations
// allow optimized operation for CRT and LCD
//
// LCD Mode, 640x480 @ 60Hz
//
// Output Clk A1 Freq. = 25.175000MHz
// Output Clk B1 Freq. = 33.333333MHz
// Output Clk C1 Freq. = 25.000000MHz
// Output Clk D1 Freq. =  3.686400MHz
//
const uchar fs6377_data_b[] = {	// lcd
0x28,	// Register 00
0xEF,	// Register 01
0x53,	// Register 02
0x03,	// Register 03
0x4B,	// Register 04
0x80,	// Register 05
0x32,	// Register 06
0x80,	// Register 07
0x94,	// Register 08
0x32,	// Register 09
0x80,	// Register 10
0xD4,	// Register 11
0x56,	// Register 12
0xF6,	// Register 13
0xF6,	// Register 14
0xE0	// Register 15
};

// CRT Mode, 640x480 @ 75Hz
//
// Output Clk A Freq. = 31.500000MHz
// Output Clk B Freq. = 33.333333MHz
// Output Clk C Freq. = 25.000000MHz
// Output Clk D Freq. =  3.686400MHz
//
const uchar fs6377_data_a[] = {	// crt
//0x08,	// Register 00 
//0xBD,	// Register 01 
//0x40,	// Register 02 
//0x03,	// Register 03 
0x10,	// Register 00 
0x3b,	// Register 01 
0x49,	// Register 02 
0x03,	// Register 03 
0x4B,	// Register 04 
0x80,	// Register 05 
0x32,	// Register 06 
0x80,	// Register 07 
0x94,	// Register 08 
0x32,	// Register 09 
0x80,	// Register 10 
0xD4,	// Register 11 
0x66,	// Register 12 
0xF6,	// Register 13 
0xF6,	// Register 14 
0xE0	// Register 15 
};



