// board specific defines for micro monitor
#define DEFAULT_BAUD_RATE   	38400
#define MON_CPU_CLOCK       	77410000

#define LOOPS_PER_USEC			5

/// CPLD controlled bits
#define BCSR_REG_ADD			0x44000000	// CPLD based BCSR
#define BCSR_REG(_x_)  			*(vuchar *)(BCSR_REG_ADD + _x_)
#define BCSR_GPIN				0x00		// 4-bit GPIO input register
#define BCSR_GPOUT				0x20		// 4-bit GPIO output register
#define BCSR_GPDIR				0x40		// 4-bit GPIO direction register, 1 = output
#define BCSR_ISTAT				0x60		// Write = Interrupt Mask, Read = Interrupt Status
#define BCSR_IMASK				0x60
#define BCSR_LED				0x80		// Write = USER LED's, Read = User Switches
#define BCSR_SW					0x80
#define BCSR_SPI				0xa0		// SPI Chip Enables
#define BCSR_I2C				0xc0		// I2C Command and Status register

// bit defines for some BCSR registers
// BCSR interrupt status and mask bits
#define BCSR_INT_GP0			0x08		// Interrupt bit from GPIO 0 = 1 when GPIO0 is input and is 0
#define BCSR_INT_SW0			0x04		// 1 = User SW0 is 0
#define BCSR_INT_CAN1			0x02		// 1 = CAN Interrupt 1 is asserted (0)
#define BCSR_INT_CAN0			0x01		// 1 = CAN Interrupt 0 is asserted (0)
// user led and switch bits
#define BCSR_LED2				0x04
#define BCSR_LED1				0x02
#define BCSR_LED0				0x01
#define BCSR_SW2				0x04
#define BCSR_SW1				0x02
#define BCSR_SW0				0x01
// SPI Chip Enables
#define BCSR_SPI2				0x04
#define BCSR_SPI1				0x02
#define BCSR_SPI0				0x01

// Write control commands to set/clr SDA and SCL
#define BCSR_I2C_CLR_ALL 		0x00	// drive both to 0
#define BCSR_I2C_SET_ALL 		0xff	// release both to hi-z
#define BCSR_I2C_CLR_SCL 		0x01	// drive SCL to 0
#define BCSR_I2C_SET_SCL 		0x02	// release SCL to hi-z
#define BCSR_I2C_CLR_SDA		0x04	// drive SDA to 0
#define BCSR_I2C_SET_SDA		0x08	// release SDA to hi-z

// Read Bit Locations
#define BCSR_I2C_SCL_RD			0x01	// read SCL
#define BCSR_I2C_SDA_RD			0x02	// read SDA

// macro for accessing the LAN91C113
#define LAN_REG_ADD				0x440000e0
#define LAN_REG(_x_)  			*(vushort *)(LAN_REG_ADD | _x_)
#define LAN_STEP				1		// LAN91C11x is on 16-bit boundries
