/* Monitor configuration file.
    General notice:
    This code is part of a boot-monitor package developed as a generic base
    platform for embedded system designs.  As such, it is likely to be
    distributed to various projects beyond the control of the original
    author.  Please notify the author of any enhancements made or bugs found
    so that all may benefit from the changes.  In addition, notification back
    to the author will allow the new user to pick up changes that may have
    been made by other users after this version of the code was distributed.

    Author: Ed Sutter
    email:  esutter@lucent.com
    phone:  908-582-2351
*/

#ifndef CONFIG_H
#define CONFIG_H

#define FOR_COGENT 0

#ifndef FOR_COGENT
#define FOR_COGENT 1
#endif

#if FOR_COGENT
#define	DEFAULT_ETHERADD "00:23:31:72:80:00"
#define	DEFAULT_IPADD "192.168.254.216"
#define	DONT_CENTER_MONHEADER
#define	WATCHDOG_MACRO	\
	{ \
	volatile unsigned register tsr_reg = 0x40000000; \
	asm volatile ("mtspr 0x3d8, %0" : "=r" (tsr_reg)); \
	}


#else

#include "xio.h"
#define	NO_UMON_STARTUP_HDR	
#define	WATCHDOG_MACRO	\
	{	\
	*(volatile unsigned long *)X_OUTPUT &= ~X_D0; \
	*(volatile unsigned long *)X_OUTPUT |= X_D0; \
	}
#endif

#define PRE_COMMANDLOOP_HOOK	csb472_setup

#define MONSTACKSIZE 	0x2000
#define CPU_NAME        "PowerPC 405GP"
#define PLATFORM_NAME   "Cogent CSB472"

#define RAM_VECTOR_TABLE    0x0
#ifndef PRE_COMMANDLOOP_HOOK
#define PRE_COMMANDLOOP_HOOK()	leds_on()
#endif

/* uart16552 definitions:
 * UART_A is wired directly to the SIO0 DB9 header for RS232.  This is
 *   the header that is closest to the Ethernet port.
 * UART_B is wired through some steering logic that allows it to be
 *   used for RS232 or RS485 depending on the steering.  Note that in
 *   the early rev of the CSB472, this port's functionality depended on
 *   the driver chip that was plugged in.  In the later revs of the CSB472,
 *   either mode could be configured based strictly on steering, no need
 *   for different parts.
 */
#define UART_A				0xef600300		/* RS232 only */
#define UART_B				0xef600400		/* RS232/RS485 */
#define CONSOLE_UART_BASE	UART_A
#define BRD_115200	4
#define BRD_57600	9
#define BRD_38400	13
#define BRD_19200	26
#define BRD_9600	52

/* LOOPS_PER_SECOND:
 * Approximately the size of a loop that will cause a 1-second delay.
 * This can be guestimated or modified with the sleep -c command at the
 * monitor command line.
 */
#define LOOPS_PER_SECOND    110000
#define TIMER_TICKS_PER_MSEC 200000

/* The CSB472 hardware simply has one bank of flash devices.
 * We define SINGLE_FLASH_DEVICE here to pull in the default
 * code from the flash driver file.
 */
#define SINGLE_FLASH_DEVICE		

/* Don't use TFS in RAM...
 * #define FLASHRAM_BASE			0x300000
 */
#define FLASHRAM_END			0x3fffff
#define FLASHRAM_SECTORSIZE		0x010000
#define FLASHRAM_SECTORCOUNT	16
#define FLASHRAM_BANKNUM		1

#ifdef FLASHRAM_BASE
#define FLASHBANKS              2
#else
#define FLASHBANKS              1
#endif
#define FLASH_BANK0_WIDTH       2

#ifdef FLASH_IS_AMD
#define FLASH_BANK0_SIZE		0x200000
#define FLASH_LARGEST_SECTOR    0x10000
#define FLASH_BANK0_BASE_ADDR	0xffe00000
#else
#define FLASH_BANK0_SIZE		0x800000
#define FLASH_LARGEST_SECTOR    0x20000
#define FLASH_BANK0_BASE_ADDR	0xff800000
#endif

#define FLASH_TIMEOUT			1000000
#define FLASH_COPY_TO_RAM

/* TFS definitions:
 *  TFSSTART:       Base address in FLASH at which TFS starts.
 *  TFSEND:         End address of TFS in FLASH.
 *  TFSSPARE:       Location of sector that is used as the spare sector
 *                  by TFS for defragmentation.
 *  TFSSPARESIZE:   Size of the spare sector used by TFS for defragmentation.
 *  TFSSECTORCOUNT: Number of eraseable sectors that TFS covers, not including
 *                  the TFSSPARE sector.
 */
#define TFSSPARESIZE			FLASH_LARGEST_SECTOR
#define TFSSTART				FLASH_BANK0_BASE_ADDR

#if FLASH_IS_AMD
#define TFSSECTORCOUNT			26
#define TFSEND					0xfff6ffff
#define FLASH_PROTECT_RANGE  	"27-34"
#else
#define TFSSECTORCOUNT			59
#define TFSEND					0xfff5ffff
#define FLASH_PROTECT_RANGE  	"60-63"
#define TFS_ALTDEVTBL_BASE		&alt_tfsdevtbl_base
#endif

#define TFSSPARE				(TFSEND+1)
#define TFS_EBIN_ELF			1
#define TFS_VERBOSE_STARTUP		0
#define TFS_AUTOBOOT_ABORTABLE

/* Specify the size of the memory block (in monitor space) that is to be
 * allocated to malloc in the monitor.  Note that this size can be dynamically
 * increased through the HEAPBASE and HEAPSTART shell variables.
 */
#define ALLOCSIZE 64*1024

#define USE_DEFAULT_PCISHOW

/* Specify inclusion of subsystems within the monitor here.
 */
#define INCLUDE_MEMCMDS         1
#define INCLUDE_EDIT            1
#define INCLUDE_DISASSEMBLER    1
#define INCLUDE_VERBOSEHELP		1
#define INCLUDE_UNZIP           1
#define INCLUDE_ETHERNET        1
#define INCLUDE_ICMP			1
#define INCLUDE_TFTP            1
#define INCLUDE_DHCPBOOT        1
#define INCLUDE_TFS             1
#define INCLUDE_TFSAPI          1
#define INCLUDE_TFSCLI          1
#define INCLUDE_TFSSYMTBL       1
#define INCLUDE_TFSSCRIPT       1
#define INCLUDE_XMODEM          1
#define INCLUDE_LINEEDIT        1
#define INCLUDE_EE              1
#define INCLUDE_FLASH           1
#define INCLUDE_MALLOC          1
#define INCLUDE_SHELLVARS       1
#define INCLUDE_GDB  	        1
#define INCLUDE_STRACE          1
#define INCLUDE_CAST            1
#define INCLUDE_STRUCT          1
#define INCLUDE_REDIRECT        1
#define INCLUDE_QUICKMEMCPY     1
#define INCLUDE_PROFILER        0
#define INCLUDE_BBC             0
#define INCLUDE_MEMTRACE        1
#define INCLUDE_SPRCMD          1
#define INCLUDE_DCRCMD          1
#define INCLUDE_TRAPCMD         1
#define INCLUDE_SYSCALLCMD      1
#define INCLUDE_STOREMAC		INCLUDE_FLASH
#define INCLUDE_XSVFCMD			1
#define INCLUDE_WDCMD			1
#define INCLUDE_HWTMR			1
#define INCLUDE_SYSLOG			1
#define INCLUDE_PORTCMD			0
#define INCLUDE_USRLVL			1
#define INCLUDE_JFFS2			0
#define INCLUDE_JFFS2ZLIB		0
#define INCLUDE_MMUCMD 			1	/* GCC 3.2 doesn't like tlbre, so if */
									/* 3.2 is used, this must be zero. */

/* Inclusion of this next file will make sure that all of the above
 * inclusions are legal; and adjust where necessary.
 */
#include "inc_check.h"

#endif  /* CONFIG_H */
