//=============================================================================
//
//      cpuio.c
//
//      CPU/Board Specific IO
//
// Author(s):    Michael Kelly, Cogent Computer Systems, Inc.
//				 Luis Torrico, Cogent Computer Systems, Inc.
// Date:         12-27-2007
// Description:  This file contains the IO functions required by Micro Monitor
//				 that are unique to each CPU/Board combination
//
//
//=============================================================================

#include "config.h"
#include "cpuio.h"
#include "genlib.h"
#include "ether.h"
#include "stddefs.h"
#include "at91sam9263.h"
#include "at91sam9263_mem.h"
#include "at91sam9263_dbgu.h"
#include "at91sam9263_gpio.h"
#include "at91sam9263_lcd.h"
#include "csb737_gpio.h"
#include "warmstart.h"
#include "fb_draw.h"

//#define CF_DEBUG

extern void	i2c_init(void);
extern void lcd_putchar(char c);
extern void putpsr(ulong);
extern ulong getpsr(void);


extern int lcd_init(void);
extern void lcd_on(void);
extern void lcd_off(void);
extern int lcd_color_depth;


extern int lcd_color_depth;
extern int lcd_fg_color;		// 0 to 15, used as lookup into VGA color table
extern int lcd_bg_color;		// 0 to 15, used as lookup into VGA color table
extern int wqvga;
uchar bcolor;

// Delay for some usecs. - Not accurate, assumes ROM mode
// and no Cache.
void udelay(int delay)
{
  volatile int i;
  for ( i = LOOPS_PER_USEC * delay; i ; i--)
	;
}

void lcd_bkl(uchar bright){

//	printf("Turning Backlight On.\n");

//	udelay(1000);
	GPIO_out(LCD_BKL);
	GPIO_set(LCD_BKL);
}

/* InitUART():
 * This is the top-level UART initialization for the monitor. 
 */
void
InitUART(int baud)
{
	// clear error bits and reset tx and rx
	DBGU_REG(DBGU_CR) = DBGU_CR_RSTSTA
					   | DBGU_CR_RSTTX
					   | DBGU_CR_RSTRX;

	// clear any pending interrupts and mask all further interrupts
	DBGU_REG(DBGU_IDR) = DBGU_INT_ALL;
	DBGU_REG(DBGU_IMR) = 0x00000000;

	// Baud divisor = MCK / 16 / baud
	DBGU_REG(DBGU_BRGR) = ((MCK/16)/baud);	// integer only

	// set the port to no parity, no loopback
	DBGU_REG(DBGU_MR) = DBGU_MR_PAR_NONE | DBGU_MR_CHMODE_NORM;

	// Enable
	DBGU_REG(DBGU_CR) = DBGU_CR_TXEN | DBGU_CR_RXEN;
}

int
ConsoleBaudSet(int baud)
{
	// Baud divisor = MCK / 16 / baud
	DBGU_REG(DBGU_BRGR) = ((MCK/16)/baud);	// integer only
	return(0);
}

//void
//cf_init(void)
//{
//	// read the CD signal to see if we have a card
//	if (GPIO_tst(CF_CD)){
//#ifdef CF_DEBUG
//		printf("No Compact FLASH Card Detected.\n");
//#endif
//		return;
//	}
//
//
//	// assign cs4 to CF
//	EBI_REG(EBI_CSA) |= EBI_CSA_CS4_CF;
//
//	// make sure the SMC controls CF_CE1/2 and we enable WAIT
////	PIOC_REG(PIO_PDR) = CF_CE1 | CF_CE2 | A_WAIT;
//
//	// set CS4 for 10 wait states, 16-bits
//	SMC_REG(SMC_CSR4) = SMC_CSR_RWHOLD(2)
//					  | SMC_CSR_RWSETUP(4)
// 					  | SMC_CSR_ACSS_3
//					  | SMC_CSR_DRP_NORMAL
//					  | SMC_CSR_DBW_16
//					  | SMC_CSR_BAT_16_2
//					  | SMC_CSR_TDF(4)
//					  | SMC_CSR_WSEN
//					  | SMC_CSR_NWS(20);
//
//	// enable power to the card
//	GPIO_out(CF_RST );	// make it an output
//	GPIO_set(CF_RST);	// hold card in reset
//
//	GPIO_out(CF_PWR);	// make it an output
//	GPIO_set(CF_PWR);	// turn card power on
//
//	udelay (100);
//
//	GPIO_clr(CF_RST);	// release card reset
//
//#ifdef CF_DEBUG
//	printf("Compact FLASH Card Detected.\n");
//#endif
//
//	udelay (10000);
//}

void
psram_init(void)
{

	// Enable pull-ups on SMC1 signals
	CCFG_REG(CCFG_EBI1_CSA) = CCFG_EBI1_CSA_DBPU;

	// set EBI1 CS0 to Setup and Pulse lengths of 1,
	// 16-bits, 3 Cycle clocks
	// address and strobe delay
//	SMC1_REG(SMC_CYCLE0) = 0x000a000a;
//	SMC1_REG(SMC_MODE0)	 = 0x00041003;
//	SMC1_REG(SMC_SETUP0) = 0x02020202;
//	SMC1_REG(SMC_MODE0)	 = 0x00041003;
//	SMC1_REG(SMC_PULSE0) = 0x05050705;
//	SMC1_REG(SMC_MODE0)	 = 0x00041003;

	// Settings for PSRAM from KCI (GreenHills Integrity)

//	SMC1_REG(SMC_SETUP0) = 0x00000202;
//	SMC1_REG(SMC_PULSE0) = 0x07070705;
//	SMC1_REG(SMC_CYCLE0) = 0x0007000a;
//	SMC1_REG(SMC_MODE0)	 = 0x00001002;

	SMC1_REG(SMC_CYCLE0) = 0x0007000a;
	SMC1_REG(SMC_MODE0)	 = 0x00001002;
	SMC1_REG(SMC_SETUP0) = 0x00000202;
	SMC1_REG(SMC_MODE0)	 = 0x00001002;
	SMC1_REG(SMC_PULSE0) = 0x07070705;
	SMC1_REG(SMC_MODE0)	 = 0x00001002;


//	udelay (10000);
}

int
devInit(int baud)
{

	// Initialize the GPIO's
	GPIO_init();

	// Initialize the UART
    InitUART(baud);

	// Initialize the PSRAM
	psram_init();

	printf("Initializing CSB737 Complete.\n");

#if INCLUDE_LCD
	// Initialize the LCD controller
	lcd_off();
	lcd_init();
	lcd_on();
	udelay (1000);
#endif

	// Turning on user LED
	GPIO_out(GPIO0);
	GPIO_clr(GPIO0);
	udelay (1);

	// Initialize the CF Socket
//	cf_init();

	// Initialize the I2C Port
	i2c_init();

	return 0;
}

void
initCPUio(void)
{
}

int
target_console_empty(void)
{
	if ((DBGU_REG(DBGU_CSR) & DBGU_INT_TXBUFE))
		return(1);
	return(0);
}

int
target_putchar(char c)
{
    /* Wait for transmit ready bit
	 */
    while(1) {
        if (DBGU_REG(DBGU_CSR) & DBGU_INT_TXRDY)
            break;
    }
	DBGU_REG(DBGU_THR) = c;
#if INCLUDE_LCD
	lcd_putchar(c);
#endif
    return((int)c);
}

int
target_gotachar()
{
    if (!(DBGU_REG(DBGU_CSR) & DBGU_INT_RXRDY))
        return(0);
    return(1);
}

/* target_getchar():
 */
int 
target_getchar(void)
{
    char    c;

    /* Retrieve character */
    c = DBGU_REG(DBGU_RHR);
    return((int)c);
}

void
target_reset(void)
{
	monrestart(INITIALIZE);
}

void
cacheInitForTarget()
{
    asm("   MRC p15, 0, r0, c1, c0, 0");
    asm("   ORR r0, r0, #0x1000");  /* bit 12 is ICACHE enable*/
    asm("   MCR p15, 0, r0, c1, c0, 0");

    /* Flush instruction cache */
    asm("   MCR p15, 0, r0, c7, c5, 0");
}

void
intsrestore(psr)
ulong     psr;
{
    putpsr(psr);
}

/*
 * Read the program status register (CPSR)
 * and set the FIQ and IRQ bits.
 */
ulong
intsoff()
{
    ulong  psr;

    psr = getpsr();

    /*
     * Set bit 6, bit 7 to disable interrupts.
     */
    putpsr(psr | 0x000000c0);
    return(psr);
}


