/* Monitor configuration file.
 *
 * General notice:
 * This code is part of a boot-monitor package developed as a generic base
 * platform for embedded system designs.  As such, it is likely to be
 * distributed to various projects beyond the control of the original
 * author.  Please notify the author of any enhancements made or bugs found
 * so that all may benefit from the changes.  In addition, notification back
 * to the author will allow the new user to pick up changes that may have
 * been made by other users after this version of the code was distributed.
 *
 * Author:	Ed Sutter
 * email:	esutter@lucent.com
 * phone:	908-582-2351
*/

/* OMIT_UNDERSCORE:
 * Define this if the version of the compiler does not insert the leading
 * underscore in all C symbols.  If there is a better way to do this,
 * someone please tell me!!
 * Run "make OMIT_UNDERSCORE=TRUE" to properly pull this in.  Don't
 * just define it here, because the makefile does some other magic to
 * adjust a few symbols in the loader map template (*.ldt) files.
 */

#ifdef OMIT_UNDERSCORE
#define _moncom moncom
#define _moncomptr moncomptr
#define _start start
#define _exception exception
#define _MonStackEnd MonStackEnd
#define _ExceptionType ExceptionType
#define _Vector4 Vector4
#define _Vector5 Vector5
#define _regtbl regtbl
#define _warmstart warmstart
#endif

/* LOOPS_PER_SECOND:
   Approximately the size of a loop that will cause a 1-second delay.
   This can be guestimated or modified with the sleep -c command at the
   monitor command line.  */
#define LOOPS_PER_SECOND	800000

/* Flash bank configuration: */
#define FLASHBANKS				1
#define FLASH_BANK0_WIDTH		2
#define FLASH_BANK0_BASE_ADDR	0x000000
#define FLASH_COPY_TO_RAM

/* TFS definitions:
 * TFSSTART:		Base address in FLASH at which TFS starts.
 * TFSEND:			End address of TFS in FLASH.
 * TFSSPARE:		Location of sector that is used as the spare sector
 * 				by TFS for defragmentation.
 * TFSSPARESIZE:	Size of the spare sector used by TFS for defragmentation.
 * TFSSECTORCOUNT:	Number of eraseable sectors that TFS covers, not including
 * 					the TFSSPARE sector.
 */
#define TFSSTART		0x28000
#define TFSEND			0x37fff
#define TFSSPARE		0x38000
#define TFSSPARESIZE	0x8000
#define TFSSECTORCOUNT	2	
#define TFS_EBIN_ELF	1
#define TFS_DISABLE_AUTODEFRAG

/* Width macros used by TFS and FLASH operations.
 * Note that only one of WIDTH8, WIDTH16 and WIDTH32 should be set and the
 * WIDTHXX_NOTUESD macros should reflect the opposite state of the WIDTH
 * macros.
 */
#define	WIDTH8		0
#define	WIDTH16		1
#define	WIDTH32		0
#define	WIDTH8_NOTUSED	1
#define	WIDTH16_NOTUSED	0
#define	WIDTH32_NOTUSED	1

/* FLASH_PROTECT_RANGE:
 * These sectors are configured to be software-protected by the monitor's
 * flash command.  Note this is a "software" protection mechanism, not
 * hardware!
 */
#define FLASH_PROTECT_RANGE	"0-4"

/* Specify CPU/PLATFORM type and name so that common code can be used
 * for a similar cpu, on different platforms.
 * The 'TYPE' definition is used for ifdefs in the code and the 'NAME'
 * is used for printfs in the code.
 */
#define CPU_NAME		"Hitachi SH2 (7043)"
#define PLATFORM_NAME	"SH2 Evaluation Board"

/* Specify the size of the memory block (in monitor space) that is to be
 * allocated to malloc in the monitor.  Note that this size can be dynamically
 * increased using the heap extension option in the heap command.
 */
#define ALLOCSIZE	64*1024
#define MONSTACKSIZE 0x2000

#define INCLUDE_MEMCMDS			0
#define INCLUDE_EDIT			0
#define INCLUDE_DISASSEMBLER	0
#define INCLUDE_UNZIP			1
#define INCLUDE_ETHERNET		0
#define INCLUDE_ICMP			0
#define INCLUDE_TFTP			0
#define INCLUDE_DHCPBOOT		0
#define INCLUDE_TFS				1
#define INCLUDE_TFSAPI			0
#define INCLUDE_TFSSYMTBL		0
#define INCLUDE_TFSSCRIPT		0
#define INCLUDE_TFSCLI			0
#define INCLUDE_XMODEM			1
#define INCLUDE_LINEEDIT		0
#define INCLUDE_EE				0
#define INCLUDE_FLASH			1
#define INCLUDE_GDB				0
#define INCLUDE_STRACE			0
#define INCLUDE_CAST			0
#define INCLUDE_STRUCT          0
#define INCLUDE_MALLOC			1
#define INCLUDE_SHELLVARS		1
#define INCLUDE_REDIRECT		0
#define INCLUDE_QUICKMEMCPY		1
#define INCLUDE_PROFILER		0
#define INCLUDE_BBC				0
#define INCLUDE_MEMTRACE		0
#define INCLUDE_STOREMAC		0
#define INCLUDE_VERBOSEHELP		1
#define INCLUDE_HWTMR			0
#define INCLUDE_PORTCMD			0
#define INCLUDE_USRLVL			0

#include "inc_check.h"
