/* Monitor configuration file.
    General notice:
    This code is part of a boot-monitor package developed as a generic base
    platform for embedded system designs.  As such, it is likely to be
    distributed to various projects beyond the control of the original
    author.  Please notify the author of any enhancements made or bugs found
    so that all may benefit from the changes.  In addition, notification back
    to the author will allow the new user to pick up changes that may have
    been made by other users after this version of the code was distributed.

    Author:	Ed Sutter
    email:	esutter@lucent.com
    phone:	908-582-2351
*/

#ifndef CONFIG_H
#define CONFIG_H

/*
 *	Processor and processor family definitions.  Used below to select the
 *	target processor.
 */

#define PLATFORM_NAME	"IBM-WALNUT Evaluation Board"
#define CPU_NAME		"PPC405GP"
#define USE_TARGET_INIT2

#define RAM_VECTOR_TABLE	0x01f00000

#define MONSTACKSIZE	0x2000

/* Baud-rate divisor definitions for common/cpu/uart_405.c: */
#define BRD_115200	0x06
#define BRD_57600	0x0c
#define BRD_38400	0x12
#define BRD_19200	0x24
#define BRD_9600	0x48

 
/* LOOPS_PER_SECOND:
 * Approximately the size of a loop that will cause a 1-second delay.
 * This can be guestimated or modified with the sleep -c command at the
 * monitor command line.
 * This value calibrated for instruction cache on, data cache on,
 * ethernet polling enabled.
 */
#define LOOPS_PER_SECOND	100000

/* The WALNUT hardware simply has one 29f040 device.  We define
 * SINGLE_FLASH_DEVICE here to pull in the default code from
 * am29f040_08_1.c driver file.
 */
#define SINGLE_FLASH_DEVICE		

/* Flash bank configuration: */
#define FLASHBANKS				2
#define FLASH_BANK0_WIDTH		1
#define FLASH_BANK0_BASE_ADDR	0xFFF80000
#define FLASH_BANK0_SIZE		0x00080000
#define FLASH_LARGEST_SECTOR	0x10000
#define FLASH_PROTECT_RANGE		"4-7"
#define FLASH_TIMEOUT			1000000
#define FLASH_COPY_TO_RAM		1

/* We are configuring a portion of RAM to "pretend" to be flash
 * so that we can overlay a TFS device onto RAM space...
 */
#define FLASHRAM_BASE			0x1b00000
#define FLASHRAM_END			0x1efffff
#define FLASHRAM_SECTORSIZE		0x20000
#define FLASHRAM_SECTORCOUNT	32
#define FLASHRAM_BANKNUM		1

/* TFS definitions:
 *  TFSSTART:	    Base address in FLASH at which TFS starts.
 *  TFSEND:		    Pointer to end of TFS space.
 *  TFSSPARE:	    Location of sector that is used as the spare sector
 *				    by TFS for defragmentation.
 *  TFSSPARESIZE:   Size of the spare sector used by TFS for defragmentation.
 *  TFSSECTORCOUNT: Number of eraseable sectors that TFS covers, not including
 *					the TFSSPARE sector.
*/
#define TFSSPARESIZE	0
#define TFSSECTORCOUNT	4
#define TFSSTART	(FLASH_BANK0_BASE_ADDR)
#define TFSEND		(FLASH_BANK0_BASE_ADDR+0x3ffff)
#define TFSSPARE	0
#define TFS_EBIN_ELF	1
#define TFS_DISABLE_AUTODEFRAG

/* Specify the size of the memory block (in monitor space) that is to be
 * allocated to malloc in the monitor.  Note that this size can be dynamically
 * increased through the HEAPBASE and HEAPSTART shell variables.
 */
#define ALLOCSIZE 52*1024

#define NO_MONLIB_PCI_STUBS
#define USE_DEFAULT_PCISHOW

/* Specify inclusion of subsystems within the monitor here.
 */
#define INCLUDE_MEMCMDS			1
#define INCLUDE_EDIT			1
#define INCLUDE_DISASSEMBLER	0
#define INCLUDE_UNZIP			1
#define INCLUDE_ETHERNET		1
#define INCLUDE_ICMP			1
#define INCLUDE_TFTP			1
#define INCLUDE_DHCPBOOT		1
#define INCLUDE_TFS				1
#define INCLUDE_TFSCLI			1
#define INCLUDE_TFSAPI			1
#define INCLUDE_TFSSYMTBL		1
#define INCLUDE_TFSSCRIPT		1
#define INCLUDE_XMODEM			1
#define INCLUDE_LINEEDIT		1
#define INCLUDE_EE				1
#define INCLUDE_FLASH			1
#define INCLUDE_MALLOC			1
#define INCLUDE_SHELLVARS		1
#define INCLUDE_STRACE			1
#define INCLUDE_CAST			1
#define INCLUDE_STRUCT          1
#define INCLUDE_REDIRECT		0
#define INCLUDE_QUICKMEMCPY		0
#define INCLUDE_PROFILER		1
#define INCLUDE_BBC				0
#define INCLUDE_MEMTRACE		1
#define INCLUDE_STOREMAC		0
#define INCLUDE_VERBOSEHELP		1
#define INCLUDE_HWTMR			0
#define INCLUDE_PORTCMD			0
#define INCLUDE_USRLVL			1
#define INCLUDE_PCI				1

/* PowerPC specific: */
#define INCLUDE_DCRCMD			1
#define INCLUDE_SPRCMD			1
#define INCLUDE_TRAPCMD			1
#define INCLUDE_SYSCALLCMD		1
#define INCLUDE_DABRCMD			0
#define INCLUDE_IABRCMD			0

/* Inclusion of this next file will make sure that all of the above
 * inclusions are legal; and adjust where necessary.
 */
#include "inc_check.h"

#endif	/* CONFIG_H */
